MikroTik.RouterOS
=================

====== ======================================
Vendor `MikroTik <http://www.mikrotik.com/>`_
OS     RouterOS
====== ======================================

MikroTik.RouterOS profile supports RouterOS based family of software routers and access points

Tested Equipment
----------------
.. supported:: MikroTik.RouterOS
